<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Core\ConfigInterpretors
{
    use \XTemplate\Core\ConfigInterpretor;
    use \XTemplate\Core\Exceptions\ConfigException;
    use \XTemplate\Core\XML;
    
    /**
     * This interpretor allows you to registrate new config interpretors. 
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class Interpretors extends ConfigInterpretor
    {
        /**
         * Parse the config entry
         * 
         * @param       XTemplate\Core\XML      $objEntry           The configuration entry
         * @throws      XTemplate\Core\Exceptions\ConfigException
         */
        protected function parse(XML $objEntry)
        {
            // Collect all entries and sort them
            foreach ($objEntry->children() as $objChild)
            {
                $strClassName = (string) $objChild;
                $strName = $objChild->getAttribute("name");
                
                // If there is no operator, throw an exception
                if ($strName === null)
                {
                    throw new ConfigException("No name registrated for interpretor '". $strClassName ."'.");
                }
                $this->objConfig->addInterpretor($strName , $strClassName);
            }
        }
    }
}
?>