<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Core\ConfigInterpretors
{
    use \XTemplate\Core\ConfigInterpretor;
    use \XTemplate\Core\XML;
    
    /**
     * This is the config interpretor registrates class overloads. You are not able to overload any of the core classes. 
     * But you can overload any other class of the engine. This gives you a greate flexibility while working on custom
     * solutions. 
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class Overload extends ConfigInterpretor
    {
        /**
         * Parse the config entry
         * 
         * @param       XTemplate\Core\XML      $objEntry           The configuration entry
         * @throws      XTemplate\Core\Exceptions\ConfigException
         */
        protected function parse(XML $objEntry)
        {
            $objEngine = $this->getEngineInstance();
            
            // Registrate all overloads at the engine instance
            foreach ($objEntry->children() as $objEntry)
            {
                // Get the classname
                $strClassName = $objEntry->getAttribute("name");
                $strNewClassName = (string) $objEntry;
                
                // Registrate the overload
                $objEngine->registrateClassOverload($strClassName, $strNewClassName);
            }
        }
    }
}
?>