<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Core
{
    /**
     * This is a helper class which contains some useful static methods. 
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class Helper
    {
        /**
         * Explodes a string, trims the array entries and removes empty entries. 
         * 
         * @param       string              $strInput
         * @param       string              $strExplode
         * @return      array
         * @throws      XTemplate\Core\Exceptions\CoreException
         */
        public static function trimExplode($strInput, $strExplode)
        {
            Params::string($strInput, __CLASS__, __FUNCTION__);
            Params::string($strExplode, __CLASS__, __FUNCTION__);
            
            // The explode char must not be empty
            if ($strExplode === "")
            {
                throw new Exceptions\CoreException("Explode char must not be empty.");
            }
            
            $arrSplit  = explode($strExplode, $strInput);
            $arrReturn = array();
            
            foreach ($arrSplit as $strEntry)
            {
                // Remove useless whitespace
                $strEntry = trim($strEntry);
                
                // Is this entry valid?
                if ($strEntry !== "")
                {
                    $arrReturn[] = $strEntry;
                }
            }
            
            return $arrReturn;
        }
        
        /**
         * Creates a path relative from a specific one. e.g. /var/www and ../index.html becomes /var/index.html
         * 
         * @param       string              $strBase        The current directory
         * @param       string              $strRel         The relative path e.g. ../test
         * @return      string
         */
        public static function createRelPath($strBase, $strRel)
        {
            Params::string($strBase, __CLASS__, __FUNCTION__);
            Params::string($strRel, __CLASS__, __FUNCTION__);
            
            //chdir($strRel);
            //return realpath($strBase);
            while (strlen($strRel) > 3 && substr($strRel, 0, 3) === "../")
            {
                $strBase = dirname($strBase);
                $strRel = substr($strRel, 3, strlen($strRel) - 3);
            }
            
            if ($strBase !== "/")
            {
                $strBase .= "/";
            }
            
            return $strBase . $strRel;
        }
    }
}
?>