<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Core
{
    /**
     * This is an extension of the SimpleXMLElement class which contains some useful functions. 
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class XML extends \SimpleXMLElement
    {
        /**
         * Returns a new XML instance from a xml file or from an XML string. If there is no file the input is assumed as
         * XML string.
         * 
         * @param       string              $varXML            The path to the XML file or an XML object which is 
         *                                                     returned as it is or an XML string
         * @return      XTemplate\Core\XML
         * @throws      XTemplate\Core\Exceptions\CoreException
         */
        public static function getInstance($varXML)
        {
            // Is the given "file" already an XML object?
            if ($varXML instanceof XML)
            {
                return $varXML;
            }
            else
            {
                Params::string($varXML, __CLASS__, __FUNCTION__);
                
                // Is there a file like this?
                if (file_exists($varXML))
                {
                    // Load the file
                    $objXML = @ simplexml_load_file($varXML, Classes::CORE_XML);
                    if (!$objXML instanceof XML)
                    {
                        // The file could not be loaded
                        throw new Exceptions\CoreException("The xml file '". $varXML ."' could not be loaded as XML.");
                    }
                }
                else
                {
                    // Assume the input is an XML string
                    $objXML = @ simplexml_load_string($varXML, Classes::CORE_XML);
                    if (!$objXML instanceof XML)
                    {
                        // The file could not be loaded
                        throw new Exceptions\CoreException("Invalid XML string.");
                    }
                }
                return $objXML;
            }
        }
        
        /**
         * Returns the value of an attribute
         * 
         * @param       string        $strName            Name of the attribute
         * @param       string        $strNameSpace        Namespace name
         * @return      string
         */
        public function getAttribute ($strName, $strNameSpace = "")
        {
            if ($this->attributes($strNameSpace, true)->$strName === null)
            {
                return null;
            }
            return (string) $this->attributes($strNameSpace, true)->$strName;
        }
        /**
         * Creates a childnode with a CDATA section in it to put there any content which you want
         * 
         * @param       string            $strName        Name of the new childnode
         * @param       string            $strValue        Content of the CDATA section
         * @return      XML
         */
        public function addCDataChild($strName, $strValue)
        {
            $objNodeOld  = dom_import_simplexml ($this);
            $objNodeNew  = new \DOMNode ();
            $objDom      = new \DOMDocument ();

            $objDataNode = $objDom->appendChild ($objDom->createElement($strName));
            $objDataNode->appendChild ($objDom->createCDATASection($strValue));
            $objNodeTarget = $objNodeOld->ownerDocument->importNode ($objDataNode, true);

            $objNodeOld->appendChild ($objNodeTarget);
            return simplexml_import_dom ($objNodeTarget, __CLASS__);
        }
    
        /**
         * Creates an array form this xml tree
         * 
         * @return       array
         */
        public function toArray()
        {
            $arrReturn = array();
            
            foreach ($this->children() as $objChild)
            {
                $strName = (string) $objChild->getName();
                
                // Does this child has got any children?
                if ($objChild->count() > 0)
                {
                    $arrReturn[$strName] = $objChild->toArray();
                }
                else
                {
                    $arrReturn[$strName] = (string) $objChild;
                }
            }
            
            return $arrReturn;
        }
    }
}
?>