<pre>
<?php
    /**
    * x:template - PHP based template engine
    * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
    * 
    * Released under the GPL License.
    * 
    * @author      Tobias Pohlen
    * @ignore
    */
    /**
    * Of course you cannot compare x:template to a great framework like phpQuery. But to measure the performance of 
    * x:template we need another template engine which supports CSS selectors. As phpQuery is well known, we choose it.
    * 
    * You have to install the phpQuery PEAR package to run this demo. 
     * 
     * In this demo, all nodes receive a certain classname. 
    */

    define ("CSS_SELECTORS", "selectors.css");
    define ("TEMPLATE", "large_template.html");

    // Load the selectors
    $hdlFile = @fopen (CSS_SELECTORS, "r");
    if (!$hdlFile)
    {
        die("Could not read css selectors.");
    }
    $strContent = @fread($hdlFile, filesize(CSS_SELECTORS));
    @fclose($hdlFile);

    if (!$strContent)
    {
        die("Could not read css selectors.");
    }

    // Transfer the selectors to an array
    $arrSelectors = explode("\n", $strContent);

    echo "Testing ". count($arrSelectors). " random CSS selectors on a ". filesize(TEMPLATE) ."bytes large document.\n\n";

    /******************************************************************************************************************/


    // Measure the time phpQuery needs, to run the CSS selectors
    require "phpQuery.php";

    $fltStart = microtime(true);
    $objDoc = phpQuery::newDocumentFile(TEMPLATE);
    $i = 0;
    foreach ($arrSelectors as $strSelector)
    {
        ++$i;
        $objDoc->find($strSelector)->addClass("class". $i);
    }
    // Render the template
    (string) $objDoc;
    $fltPhpQueryDuration = (microtime(true) - $fltStart) * 1000;

    echo "phpQuery: ". $fltPhpQueryDuration ."ms\n";

    /******************************************************************************************************************/

    // Measure the time x:template needs to run the CSS selectors
    // It's important to notice that x:template always selects from the root of the DOM structure whilst phpQuery always 
    // selects from the <body>-tag.

    $fltStart = microtime(true);
    require "../../Engine.php";

    class Performance extends XTemplate\ComfortView
    {
        const TEMPLATE = TEMPLATE;

        protected function _render() 
        {
            // Get the selectors
            global $arrSelectors;

            $i = 0;
            foreach ($arrSelectors as $strSelector)
            {
                ++$i;
                $this[$strSelector]->addClass("class". $i);
            }
        }
    }
    $objXTemplate = new Performance();
    // Render the template
    (string) $objXTemplate;

    $fltXTemplateDuration = (microtime(true) - $fltStart) * 1000;

    echo "x:template: ". $fltXTemplateDuration ."ms\n";
    echo "Ratio: ". (100 * $fltPhpQueryDuration / $fltXTemplateDuration) ."%";
?>
</pre>