<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate
{
    /**
     * This class provides a typesafe use of callback functions.
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     0.5
     */
    class FuncWrapper
    {
        /**
         * Callback
         * @var mixed 
         */
        private $varCallback = null;
        /**
         * Default arguments
         * @var array 
         */
        private $arrDefaultArgs = array();
        
        /**
         * Creates a new callback instance.
         * 
         * @param       mixed               $varCallback
         * @param       ...                 Default arguments
         * @throws      XTemplate\Exceptions\FuncWrapperException
         */
        public function __construct($varCallback)
        {
            $this->varCallback = $varCallback;
            // Verify that the callback is valid
            if (!is_callable($varCallback))
            {
                throw new Exceptions\FuncWrapperException("Invalid callback.");
            }
            
            // Get the default arguments
            $this->arrDefaultArgs = func_get_args();
            array_shift($this->arrDefaultArgs);
        }
        
        /**
         * Call the user function
         * 
         * @return      mixed 
         */
        public function __invoke()
        {
            $arrArgs = func_get_args();
            
            // Append the default arguments
            foreach ($this->arrDefaultArgs as $varArg)
            {
                $arrArgs[] = $varArg;
            }
            
            return call_user_func_array($this->varCallback, $arrArgs);
        }
    }
}
?>