<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Interfaces
{
    /**
     * Classes which implement this interface can handle subviews. SubViews are XTemplate\View instances which can be
     * assigned to a class which will be inserted at a certain position in the current template. The position is marked
     * by a xsub-tag:
     * 
     * <xsub name="example" />
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    interface SubView
    {
        /**
         * Assigns a subview
         * 
         * @param       string              $strName        The name of the subview
         * @param       XTemplate\SubView   $objDoc         The subview document
         */
        public function assignSubView($strName, \XTemplate\SubView $objDoc);
        
        /**
         * Returns the subviews assigned under a certain name. If there are no subviews an empty object storage is 
         * returned.
         * 
         * @param       string              $strName        The name of the subview
         * @return      XTemplate\SubViewStorage
         */
        public function getAssignedSubViews($strName);
        
        /**
         * Appends the subviews to a certain element in the template. e.g.:
         * You add multiple subviews in your controller to the view under the name "content". Now you want to put these
         * views to the element with the ID content:
         * 
         * $this->attachSubViews("#content", "content");
         * 
         * @param       string              $strSelector    A CSS selector which finds the corresponding nodes or an
         *                                                  instance of XTemplate\Interfaces\NodeEdit.
         * @param       string              $strSubViewName The name of the subviews which shall be attached
         */
        public function attachSubViews($strSelector, $strSubViewName);
    }
}
?>