<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Selectors
{
    use \XTemplate\Core\Params;
    
    /**
     * This is the selector model which contains the different parts of the final xpath selector. Please do not change 
     * anything in this class without knowning what you are doing. These methods are called very often. A little change
     * may cause a significant performance lack.
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class SelectorModel
    {
        /**
         * XPath stack
         * @var array
         */
        private $arrPathStack = array();
        /**
         * Attribute stack
         * @var array
         */
        private $arrAttributeStack = array();
        
        /**
         * Pushes something on the path stack
         * 
         * @param       string              $strXPathSnippet
         */
        public function pushPath($strXPathSnippet)
        {
            // No typecheck for a better performance
            $this->arrPathStack[] = $strXPathSnippet;
        }
        
        /**
         * Pushes something on the attribute stack
         * 
         * @param       string              $strXPathSnippet
         */
        public function pushAttribute($strXPathSnippet)
        {
            // No typecheck for a better performance
            $this->arrAttributeStack[] = $strXPathSnippet;
        }
        
        /**
         * Creates the final xpath and returns it
         * 
         * @return      string
         */
        public function getXPath()
        {
            $strSelector = implode("/", $this->arrPathStack);
            
            // Are there any attribute values?
            if (count($this->arrAttributeStack) > 0)
            {
                return $strSelector. "[". implode(" and ", $this->arrAttributeStack) . "]";
            }
            else
            {
                return $strSelector;
            }
        }
        
        /**
         * Converts the model datas to the xpath string
         * 
         * @return      string
         */
        public function __toString()
        {
            return $this->getXPath();
        }
        
        /**
         * Returns the last element from the path stack and removes it from the stack
         * 
         * @return      string
         */
        public function popPath()
        {
            return array_pop($this->arrPathStack);
        }
        
        /**
         * Returns the last elment from the attribute stack and removes it from the stack.
         * 
         * @return      string
         */
        public function popAttribute()
        {
            return array_pop($this->arrAttributeStack);
        }
        
        /**
         * Returns the current pash stack
         * 
         * @return      array 
         */
        public function getPathStack()
        {
            return $this->arrPathStack;
        }
        
        /**
         * Returns the current attribute stack
         * 
         * @return      array 
         */
        public function getAttributeStack()
        {
            return $this->arrAttributeStack;
        }
    }
}
?>