<?php
namespace XTemplate
{
    /**
     * This is the base class of all subviews. Sub view means the html must not be a complete HTML template. 
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     $Id$ 
     */
    abstract class SubView extends ViewBase
    {
        /**
         * Overwrite the loadHTML method to wrap the template into a valid html construct. We do not overwrite the 
         * native loadHTML()-method since it changed from PHP 5.3 to 5.4.
         * 
         * @param       string          $strTemplate        The template string
         * @param       int             $intOptions         Flags
         * @return      bool
         */
        protected function _loadHTML($strTemplate)
        {
            // The body is wrapped in <remove>-tags to have one "documentElement" to append the whole view as subview
            return parent::loadHTML(sprintf('
                <!DOCTYPE html>
                <html>
                    <head>
                        <meta http-equiv="Content-Type" content="text/html; charset=%s"/>
                    </head>
                    <body><remove>%s</remove></body>
                </html>
            ', Core\Constants::DOM_CHARSET, $strTemplate));
        }
        
        /**
         * Saves the html and makes shure only the body will be returned
         * 
         * @return      string
         */
        public function saveHTML()
        {
            $arrMatch = array();
            switch (preg_match("#<body[^>]*>([\w\W]*)</body[^>]*>#u", parent::saveHTML(), $arrMatch))
            {
                case false:
                    // The regex is illegal
                    throw new Exceptions\RenderException("Could not extract body.");
                    break;
                
                case 0:
                    // The body was removed
                    return "";
                    break;
                
                default:
                    // Return the body content
                    return $arrMatch[1];
                    break;
            }
        }
        
        /**
         * Returns the correct document element
         * 
         * @return      DOMElement
         */
        public function getDocumentElement()
        {
            // Search for the remove tags
            $objRemoveTags = $this->getElementsByTagName("remove");
            $intLength = $objRemoveTags->length;
            
            if ($intLength > 0)
            {
                return $objRemoveTags->item(0);
            }
            else
            {
                // Could not find the corresponding remove tag, return the real documentElement
                return $this->documentElement;
            }
        }
    }
}   
?>