<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Test
{
    error_reporting(-1);
    
    require_once "Test.php";
    require_once "TestCase.php";
    require_once "Exceptions/TestException.php";
    
    /**
     * This controller guides the user through the test. 
     * 
     * @author      Tobias Pohlen
     * @version     $Id$ 
     * @package     xtemplate
     */
    class TestController
    {
        /**
         * Messages whiche are sent to the user
         * @var array
         */
        private $arrMessages = array();
        /**
         * Datas which are sent to the user
         * @var array
         */
        private $arrDatas = array();
        
        /**
         * Creates a new testcontroller
         */
        public function __construct()
        {
            // Get the action
            if (!isset($_GET["action"]))
            {
                $_GET["action"] = "invalid";
            }
            
            switch ($_GET["action"])
            {
                case "getList":
                    $this->createList();
                    break;
                
                case "getResultPage":
                    $this->createResultPage();
                    break;
                
                default:
                    $this->invalidAction();
                    break;
            }
        }
        
        public function __destruct()
        {
            // Create the user output
            $arrOut = array(
                "messages" => $this->arrMessages, 
                "datas" => $this->arrDatas
            );
            
            echo json_encode($arrOut);
        }
        
        
        /**
         * Invalid action method. When any unknown action is requested
         */
        private function invalidAction()
        {
            $this->addMessage("Invalid action parameter '". $_GET["action"] ."'.");
        }
        
        /**
         * Creates a list of all testcases
         */
        private function createList()
        {
            $strTestDir = dirname(__FILE__) . Test::PATH_SEPARATOR . "Cases". Test::PATH_SEPARATOR;
            
            // Try to open the test case directory
            $hdlDir = @ opendir($strTestDir);
            if (!$hdlDir)
            {
                $this->addMessage("Could not open testcase directory '". $strTestDir ."'.");
                return;
            }
            
            $arrDatas = array();
            
            while ($strFilename = @ readdir($hdlDir))
            {
                if ($strFilename != "." && $strFilename != ".." && is_dir($strTestDir . $strFilename))
                {
                    $arrDatas[] = $strFilename;
                }
            }
            
            $this->addDatas("testcases", $arrDatas);
            
            // Create a new testsession
            ob_start();
            $objTest = Test::getInstance();
            $strMessage = ob_get_clean();
            
            if ($strMessage !== "")
            {
                $this->addMessage($strMessage);
            }
            $this->addDatas("testsession", $objTest->getFileName());
        }
        
        /**
         * Creates the html code for the result page
         */
        private function createResultPage()
        {
            $objTest = Test::getInstance();
            
            $strResult = "<h2>Results</h2>";
            
            $objLog = $objTest->getLog();
            
            $strResult .= "<p><strong>Log infos</strong><br />";
            $strResult .= "date: ". $objLog->info->date . "<br />";
            $strResult .= "PHP Version: ". $objLog->info->php_version . "<br />";
            $strResult .= "PHP OS: ". $objLog->info->php_os . "<br />";
            $strResult .= "PHP SAPI: ". $objLog->info->php_sapi . "</p>";
            
            $intTotal = 0;
            $intFailed = 0;
            foreach ($objLog->logs->children() as $objLogEntry)
            {
                $intTotal++;
                if ((string) $objLogEntry->result === "false")
                {
                    $intFailed++;
                }
                $strResult .= "<div class=\"logresult ".$objLogEntry->result ."\">";
                $strResult .= "<strong>ID: ". $objLogEntry->case_id ."</strong><br />";
                $strResult .= "Time: ". $objLogEntry->time ."ms<br />";
                $strResult .= "Comment:<br />";
                $strResult .= "<pre>". $objLogEntry->comment ."</pre>";
                $strResult .= "</div>";
            }
            
            $strResult .= "<div class=\"logresult true\">Tests done: ". $intTotal . "<br />";
            $strResult .= "Tests failed: ". $intFailed ."</div>";
            $this->addDatas("results", $strResult);
        }
        
        /**
         * Adds a message
         * 
         * @param       string              $strMessage
         */
        private function addMessage($strMessage)
        {
            $this->arrMessages[] = $strMessage;
        }
        
        /**
         * Adds datas
         * 
         * @param       string              $strDataName
         * @param       mixed               $varDatas
         */
        private function addDatas($strDataName, $varDatas)
        {
            $this->arrDatas[$strDataName] = $varDatas;
        }
    }
    
    new TestController;
}
?>
