<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Test\UnitTests\Core
{
    use \XTemplate\Engine;
    
    $strCurrentDirectory = dirname(__FILE__);
    require_once dirname(dirname(dirname($strCurrentDirectory))) . "/Engine.php";
    
    /**
     * Test for the Helper class. 
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     $Id$ 
     */
    class Helper extends \PHPUnit_Framework_TestCase
    {
        /**
         * Tests if trimexplode works properly in a usual case. 
         */
        public function testTrimExplodeUsual()
        {
            // Input string
            $strInput = "a,b,c,,d,e,f,,,,,h   ,ee ,, eee ee , ";
            $arrOutput = \XTemplate\Core\Helper::trimExplode($strInput, ",");
            
            $this->assertEquals(
                    array("a","b","c","d","e","f","h","ee","eee ee"),
                    $arrOutput
            );
        }
        
        /**
         * Tests if trimexplode works properly if no explode char is given. 
         * 
         * @expectedException XTemplate\Core\Exceptions\CoreException
         */
        public function testTrimExplodeEmptyExplode()
        {
            // Input string
            $strInput = "a,b,c,,d,e,f,,,,,h   ,ee ,, eee ee , ";
            $arrOutput = \XTemplate\Core\Helper::trimExplode($strInput, "");
        }
        
        /**
         * Tests if trimexplode works properly when the explode string is longer than the input
         */
        public function testTrimExplodeLongExplode()
        {
            $arrOut = \XTemplate\Core\Helper::trimExplode("a", "ab");
            $this->assertEquals(array("a"), $arrOut);
        }
        
        /**
         * Tests if createRelPath works properly. 
         */
        public function testCreateRelPathUsual()
        {
            $strRel   = "../../../test";
            $strPath  = "/var/www/vhosts/xtemplate.net";
            
            $strResult = \XTemplate\Core\Helper::createRelPath($strPath, $strRel);
            
            $this->assertEquals("/var/test", $strResult);
        }
        
        /**
         * Tests if the method throws an exception when the rel path is too deep. 
         */
        public function testCreateRelPathTooDeep()
        {
            $strRel   = "../../../test";
            $strPath  = "/var";
            
            $strResult = \XTemplate\Core\Helper::createRelPath($strPath, $strRel);
            
            $this->assertEquals("/test", $strResult);
        }
    }
}
?>