<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Test\UnitTests\Core
{
    use \XTemplate\Engine;
    
    $strCurrentDirectory = dirname(__FILE__);
    require_once dirname(dirname(dirname($strCurrentDirectory))) . "/Engine.php";
    require_once dirname($strCurrentDirectory) . "/DummyClasses/DummyToString.php";
    require_once dirname($strCurrentDirectory) . "/DummyClasses/Dummy1.php";
    
    /**
     * Test for the parameter checker
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     $Id$ 
     */
    class Params extends \PHPUnit_Framework_TestCase
    {
        /**
         * Tests the string validation for basic type: boolean (true).
         */
        public function testToStringBooleanTrue()
        {
            $b = true;
            \XTemplate\Core\Params::string($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === "1");
        }
        
        /**
         * Tests the string validation for basic type: boolean (false).
         */
        public function testToStringBooleanFalse()
        {
            $b = false;
            \XTemplate\Core\Params::string($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === "");
        }
        
        /**
         * Tests the string validation for basic type: integer.
         */
        public function testToStringInteger()
        {
            $i = 123;
            \XTemplate\Core\Params::string($i, __CLASS__, __FUNCTION__);
            $this->assertTrue($i === "123");
        }
        
        /**
         * Tests the string validation for basic type: double.
         */
        public function testToStringDouble()
        {
            $d = 123.23;
            \XTemplate\Core\Params::string($d, __CLASS__, __FUNCTION__);
            $this->assertTrue($d === "123.23");
        }
        
        /**
         * Tests the string validation for basic type: string.
         */
        public function testToStringString()
        {
            $s = "hello world";
            \XTemplate\Core\Params::string($s, __CLASS__, __FUNCTION__);
            $this->assertTrue($s === "hello world");
        }
        
        /**
         * Tests the string validation for basic type: object with __toString method.
         */
        public function testToStringObjectOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\DummyToString;
            \XTemplate\Core\Params::string($o, __CLASS__, __FUNCTION__);
            $this->assertTrue($o === \XTemplate\Test\UnitTests\DummyClasses\DummyToString::TO_STRING);
        }
        
        /**
         * Tests the string validation for basic type: object without __toString method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToStringObjectNotOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\Dummy1;
            \XTemplate\Core\Params::string($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: array.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToStringArray()
        {
            $a = array(1,2,3);
            \XTemplate\Core\Params::string($a, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: boolean (true).
         */
        public function testToIntBooleanTrue()
        {
            $b = true;
            \XTemplate\Core\Params::int($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === 1);
        }
        
        /**
         * Tests the string validation for basic type: boolean (false).
         */
        public function testToIntBooleanFalse()
        {
            $b = false;
            \XTemplate\Core\Params::int($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === 0);
        }
        
        /**
         * Tests the string validation for basic type: integer.
         */
        public function testToIntInteger()
        {
            $i = 123;
            \XTemplate\Core\Params::int($i, __CLASS__, __FUNCTION__);
            $this->assertTrue($i === 123);
        }
        
        /**
         * Tests the string validation for basic type: double.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToIntDouble()
        {
            $d = 123.23;
            \XTemplate\Core\Params::int($d, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: string.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToIntString()
        {
            $s = "hello world";
            \XTemplate\Core\Params::int($s, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object with __toString method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToIntObjectOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\DummyToString;
            \XTemplate\Core\Params::int($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object without __toInt method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToIntObjectNotOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\Dummy1;
            \XTemplate\Core\Params::int($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: array.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToIntArray()
        {
            $a = array(1,2,3);
            \XTemplate\Core\Params::int($a, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: boolean (true).
         */
        public function testToDoubleBooleanTrue()
        {
            $b = true;
            \XTemplate\Core\Params::double($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === 1.0);
        }
        
        
        /**
         * Tests the string validation for basic type: boolean (false).
         */
        public function testToDoubleBooleanFalse()
        {
            $b = false;
            \XTemplate\Core\Params::double($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === 0.0);
        }
        
        /**
         * Tests the string validation for basic type: integer.
         */
        public function testToDoubleInteger()
        {
            $i = 123;
            \XTemplate\Core\Params::double($i, __CLASS__, __FUNCTION__);
            $this->assertTrue($i === 123.0);
        }
        
        /**
         * Tests the string validation for basic type: double.
         */
        public function testToDoubleDouble()
        {
            $d = 123.23;
            \XTemplate\Core\Params::double($d, __CLASS__, __FUNCTION__);
            $this->assertTrue($d === 123.23);
        }
        
        /**
         * Tests the string validation for basic type: string.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToDoubleString()
        {
            $s = "hello world";
            \XTemplate\Core\Params::double($s, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object with __toString method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToDoubleObjectOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\DummyToString;
            \XTemplate\Core\Params::double($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object without __toInt method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToDoubleObjectNotOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\Dummy1;
            \XTemplate\Core\Params::double($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: array.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToDoubleArray()
        {
            $a = array(1,2,3);
            \XTemplate\Core\Params::double($a, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: boolean (true).
         */
        public function testToBoolBooleanTrue()
        {
            $b = true;
            \XTemplate\Core\Params::bool($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === true);
        }
        
        
        /**
         * Tests the string validation for basic type: boolean (false).
         */
        public function testToBoolBooleanFalse()
        {
            $b = false;
            \XTemplate\Core\Params::bool($b, __CLASS__, __FUNCTION__);
            $this->assertTrue($b === false);
        }
        
        /**
         * Tests the string validation for basic type: integer.
         */
        public function testToBoolIntegerTrue()
        {
            $i = 123;
            \XTemplate\Core\Params::bool($i, __CLASS__, __FUNCTION__);
            $this->assertTrue($i === true);
        }
        
        /**
         * Tests the string validation for basic type: integer.
         */
        public function testToBoolIntegerFalse()
        {
            $i = 0;
            \XTemplate\Core\Params::bool($i, __CLASS__, __FUNCTION__);
            $this->assertTrue($i === false);
        }
        
        /**
         * Tests the string validation for basic type: double.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToBoolDouble()
        {
            $d = 123.23;
            \XTemplate\Core\Params::bool($d, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: string.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToBoolString()
        {
            $s = "hello world";
            \XTemplate\Core\Params::bool($s, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object with __toString method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToBoolObjectOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\DummyToString;
            \XTemplate\Core\Params::bool($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: object without __toInt method.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToBoolObjectNotOK()
        {
            $o = new \XTemplate\Test\UnitTests\DummyClasses\Dummy1;
            \XTemplate\Core\Params::bool($o, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests the string validation for basic type: array.
         * 
         * @expectedException PHPUnit_Framework_Error_Warning
         */
        public function testToBoolArray()
        {
            $a = array(1,2,3);
            \XTemplate\Core\Params::bool($a, __CLASS__, __FUNCTION__);
        }
        
        /**
         * Tests check type for null. 
         */
        public function testCheckType()
        {
            // Null must always be ok.
            \XTemplate\Core\Params::checkType(null, "string");
            \XTemplate\Core\Params::checkType(null, "integer");
            \XTemplate\Core\Params::checkType(null, "double");
            \XTemplate\Core\Params::checkType(null, "float");
            \XTemplate\Core\Params::checkType(null, "boolean");
            \XTemplate\Core\Params::checkType(null, "array");
            \XTemplate\Core\Params::checkType(null, "object");
            \XTemplate\Core\Params::checkType(null, "null");
        }
        
        /**
         * Tests the array check.
         * 
         * @expectedException \XTemplate\Exceptions\ModelException
         */
        public function testCheckTypeArrayException()
        {
            \XTemplate\Core\Params::checkType("dummy", "array");
        }
        
        /**
         * Tests the array check.
         */
        public function testCheckTypeArray()
        {
            \XTemplate\Core\Params::checkType(array(), "array");
        }
        
        /**
         * Tests the object check.
         */
        public function testCheckTypeObject()
        {
            $o = new \stdClass();
            \XTemplate\Core\Params::checkType($o, "stdClass");
        }
        
        /**
         * Tests the object check.
         * 
         * @expectedException \XTemplate\Exceptions\ModelException
         */
        public function testCheckTypeObjectException()
        {
            $o = new \stdClass();
            \XTemplate\Core\Params::checkType($o, "stdClass2");
        }
    }
}
?>