<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Test\UnitTests\Selectors
{
    use \XTemplate\Engine;
    
    $strCurrentDirectory = dirname(__FILE__);
    require_once dirname(dirname(dirname($strCurrentDirectory))) . "/Engine.php";
    require_once dirname($strCurrentDirectory) . "/DummyClasses/DummySelector.php";
    require_once dirname($strCurrentDirectory) . "/DummyClasses/DummyParser.php";
    
    /**
     * This test is for the CSS parser. Because the selectors are all set through the configuration, it's impossible to
     * test only the parser code. Some code from the configuration and config interpretors for the selector have to be
     * executed, too. But there is a unit test for the configuration to make shure it works properly. So if this test
     * fails, please check if the configuration test is wrong, too.
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     $Id$ 
     */
    class Parser extends \PHPUnit_Framework_TestCase
    {
        /**
         * Parser instance
         * @var XTemplate\Test\UnitTests\DummyClasses\DummyParser 
         */
        private $objParser = null;
        
        /**
         * Creates the test environment 
         */
        protected function setUp()
        {
            // Create a new DOM document for the parser
            $objDocument = new \DOMDocument(
                    \XTemplate\Core\Constants::DOM_VERSION, \XTemplate\Core\Constants::DOM_CHARSET);
            
            $objDocument->loadXML('
                <div>
                    <p>TEST</p>
                </div>
            ');
            $this->objParser = new \XTemplate\Test\UnitTests\DummyClasses\DummyParser(
                    $objDocument->documentElement, 
                    $objDocument, 
                    new \XTemplate\Engine(new \XTemplate\Core\XML('
                        <x:config xmlns:x="http://xtemplate.net/xmlns.html">
                            <x:interpretors name="interpretors">
                                <interpretor name="selectors">XTemplate\Core\ConfigInterpretors\Selectors</interpretor>
                            </x:interpretors>
                            <x:selectors name="selectors">
                                <path operator="#">\XTemplate\Test\UnitTests\DummyClasses\DummySelector</path>
                            </x:selectors>
                        </x:config>
                    '))
            );
        }
        
        /**
         * Tests if the operators are escaped correctly
         */
        public function testGetOperators()
        {
            $this->assertEquals(
                array("\|", "\+", "\{", "\}", "\[", "\]", "\*", "\-", "\.", "\/", "\^", '\$'), 
                \XTemplate\Test\UnitTests\DummyClasses\DummyParser::getOperators(
                    array(
                        "|" => "", 
                        "+" => "", 
                        "{" => "", 
                        "}" => "", 
                        "[" => "", 
                        "]" => "", 
                        "*" => "", 
                        "-" => "", 
                        "." => "", 
                        "/" => "", 
                        "^" => "", 
                        '$' => ""
                    )
                )
            );
        }
        
        /**
         * Tests if getOperators acts correctly if the array is empty 
         */
        public function testGetOperatorsEmpty()
        {
            $this->assertEquals(array(), \XTemplate\Test\UnitTests\DummyClasses\DummyParser::getOperators(array()));
        }
        
        /**
         * Tests if selector instances are created correctly 
         */
        public function testCreateSelectorInstanceValid()
        {
            $arrTest = array();
            
            $this->objParser->createSelectorInstance($arrTest, "#", "XTemplate\Test\UnitTests\DummyClasses\DummySelector");
            $this->assertTrue($arrTest["#"] instanceof \XTemplate\Test\UnitTests\DummyClasses\DummySelector);
        }
        
        /**
         * Tests if selector instaces are created when the class is not a valid selector
         * 
         * @expectedException XTemplate\Selectors\Exceptions\SelectorException
         */
        public function testCreateSelectorInstanceInvalid()
        {
            $arrTest = array();
            $this->objParser->createSelectorInstance($arrTest, "#", "\stdClass");
        }
        
        /**
         * Tests if the xpath is created correctly
         */
        public function testCreateXPath1()
        {
            $arrXPaths = $this->objParser->createXPath("#foo");
            $this->assertCount(1, $arrXPaths);
            $this->assertCount(1, $arrXPaths[0]);
            $this->assertEquals("descendant::*/foo", $arrXPaths[0][0]->getXPath());
        }
        
        /**
         * Tests if the xpath is created correctly
         */
        public function testCreateXPath2()
        {
            $arrXPaths = $this->objParser->createXPath("foo");
            $this->assertCount(1, $arrXPaths);
            $this->assertCount(1, $arrXPaths[0]);
            $this->assertEquals("descendant::foo", $arrXPaths[0][0]->getXPath());
        }
        
        /**
         * Tests if the xpath is created correctly
         * 
         * @expectedException XTemplate\Selectors\Exceptions\SelectorException
         */
        public function testCreateXPathInvalid1()
        {
            $this->objParser->createXPath("");
        }
        
        /**
         * Tests if the xpath is created correctly
         * 
         * @expectedException XTemplate\Selectors\Exceptions\SelectorException
         */
        public function testCreateXPathInvalid2()
        {
            $this->objParser->createXPath("%sdf");
        }
    }
}
?>