<?php
/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 */
namespace XTemplate\Test\UnitTests\Selectors
{
    use \XTemplate\Engine;
    
    $strCurrentDirectory = dirname(__FILE__);
    require_once dirname(dirname(dirname($strCurrentDirectory))) . "/Engine.php";
    
    /**
     * This test makes shure the selector model works properly. 
     * 
     * @author      Tobias Pohlen
     * @package     xtemplate
     * @version     $Id$ 
     */
    class SelectorModel extends \PHPUnit_Framework_TestCase
    {
        /**
         * Current model
         * @var XTemplate\Selectors\SelectorModel 
         */
        private $objModel = null;
        
        /**
         * Creates a new model for every test. 
         */
        public function setUp()
        {
            $this->objModel = new \XTemplate\Selectors\SelectorModel;
        }
        
        /**
         * Tests if you can add something onto the path stack . 
         */
        public function testPushPath()
        {
            $this->objModel->pushPath("test");
            $arrStack = $this->objModel->getPathStack();
            
            $this->assertEquals(array("test"), $arrStack);
        }
        
        /**
         * Tests if you can remove the last thing from the stack. 
         * 
         * @depends testPushPath
         */
        public function testPopPath()
        {
            $this->objModel->pushPath("test");
            $this->objModel->pushPath("test2");
            $arrStack = $this->objModel->getPathStack();
            
            $this->assertEquals(array("test", "test2"), $arrStack);
            
            $this->assertEquals("test2", $this->objModel->popPath());
            
            $this->assertEquals(array("test"), $this->objModel->getPathStack());
        }
        
        /**
         * Tests if you can add something onto the Attribute stack . 
         */
        public function testPushAttribute()
        {
            $this->objModel->pushAttribute("test");
            $arrStack = $this->objModel->getAttributeStack();
            
            $this->assertEquals(array("test"), $arrStack);
        }
        
        /**
         * Tests if you can remove the last thing from the stack. 
         * 
         * @depends testPushAttribute
         */
        public function testPopAttribute()
        {
            $this->objModel->pushAttribute("test");
            $this->objModel->pushAttribute("test2");
            $arrStack = $this->objModel->getAttributeStack();
            
            $this->assertEquals(array("test", "test2"), $arrStack);
            
            $this->assertEquals("test2", $this->objModel->popAttribute());
            
            $this->assertEquals(array("test"), $this->objModel->getAttributeStack());
        }
        
        /**
         * Verifies the xpath creation is correct.
         * 
         * @depends testPushAttribute
         * @depends testPushPath
         */
        public function testXPath()
        {
            $this->objModel->pushPath("test1");
            $this->objModel->pushPath("test2");
            $this->objModel->pushPath("test3");
            
            $this->objModel->pushAttribute("test4");
            $this->objModel->pushAttribute("test5");
            $this->objModel->pushAttribute("test6");
            
            $strXPath = $this->objModel->getXPath();
            
            $this->assertEquals("test1/test2/test3[test4 and test5 and test6]", $strXPath);
        }
    }
}
?>