/**
 * x:template - PHP based template engine
 * Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
 * 
 * Released under the GPL License.
 * 
 * Javascript to perform the tests for the engine. 
 * 
 * @author      Tobias Pohlen
 * @version     $Id$ 
 * @package     xtemplate
 */
(function($, window) {
    "use strict";
    var strSessionName = "",
    arrTestCases = [],
    intCurrentTest = 0,
    objBoxes = null, 
    objStatus = null,
    intStep = 0;
    
    /**
     * Creates a new box and returns the dom element
     * 
     * @return  dom element of the box
     */
    function _createBox()
    {
        var objNewBox = $("<div class=\"box\"></div>").hide();
        objBoxes.append(objNewBox);
        objNewBox.show("fast");
        return objNewBox;
    }
    
    /**
     * Shows the messages which were sent by the server
     */
    function _readMessages(arrMessages)
    {
        for (var i = 0; i < arrMessages.length; i++)
        {
            _createBox().html(arrMessages[i]);
        }
    }
    
    /**
     * Performs the single tests
     */
    function _performTests()
    {
        var objBox = _createBox();
        
        // Add the progressbar
        objBox.html("<div class=\"progress\"></div>");
        $("div.progress").progressbar({
            value : 0
        });
        objStatus = _createBox();
        
        // Perform the testcases
        _performCases();
    }
    
    /**
     * Performs the testcases
     */
    function _performCases()
    {
        // Update the progressbar
        if (arrTestCases.length > 0)
        {
            $("div.progress").progressbar("value", parseInt(intCurrentTest * 100 / arrTestCases.length, 10));
        }
        
        if (intCurrentTest >= arrTestCases.length)
        {
            // Load the results
           $.ajax({
                url : "TestController.php", 
                data : {
                    action : "getResultPage", 
                    test : strSessionName
                }, 
                error : function(data) {
                    _createBox().html("Could fetch test results.");
                }, 
                success : function(data) {
                    try {
                        var objJSON = $.parseJSON(data);
                    }
                    catch (e) {
                        _createBox().html("Invlid test controller content.");
                        return;
                    }
                    
                    _readMessages(objJSON.messages);
                    
                    // Remove the progressbar
                    $("div.progress").parents(".box").remove();
                    objStatus.remove();

                    _createBox().html(objJSON.datas.results);
                }
            });
            return;
        }
        
        objStatus.html("Performing test: " + (intCurrentTest + 1) + " of " + arrTestCases.length +".");
        $.ajax({
            url : "Cases/" + arrTestCases[intCurrentTest] + "/index.php", 
            data : {
                test : strSessionName
            }, 
            error : function(data) {
                _createBox().html("Test '" + arrTestCases[intCurrentTest] + "' couldn't be performed.");
                intCurrentTest++;
                _performCases();
            }, 
            success : function(data) {
                if (data != "")
                {
                    _createBox().html("Test '" + arrTestCases[intCurrentTest] + "' failed.\n\n" + data);
                }
                intCurrentTest++;
                _performCases();
            }
        });
    }
    
    /**
     * Starts the testsession
     */
    function _start() 
    {
        // Load the list from the server
        $.ajax({
            url : "TestController.php", 
            data : {
                action : "getList"
            }, 
            error : function(data) {
                _createBox().html("Could not start the testsession.");
            }, 
            success : function(data) {
                try {
                    var objJSON = $.parseJSON(data);
                }
                catch (e) {
                    _createBox().html("Invlid test controller content.");
                    return;
                }
                arrTestCases = objJSON.datas.testcases;
                strSessionName = objJSON.datas.testsession;
                _readMessages(objJSON.messages);
                
                // Perform the single tests
                _performTests();
            }
        });
    }
    
    $(function() {
        objBoxes = $("#boxes");
        
        // Start button
        $("#start").click(function() {
            // Start the testsession
            _start();
            $(this).parents(".box").hide();
            return false;
        });
        
    });
})(jQuery, window);