#!/bin/bash
##
# x:template - PHP based template engine
# Copyright (c) 2011 - 2012 by Tobias Pohlen <tobias.pohlen@xtemplate.net>
# 
# Released under the GPL License.
##
##
# Testsuite to be executed in the shell
# Author: Tobias Pohlen
##
echo "x:template 0.5 - Tobias Pohlen"
echo ""
 
# Define the testcase directory
TEST_CASES="Test/Cases/*"

# Counter for the result
DONE=0
FAILED=0
echo ""

echo "1. UNITTESTS"
echo "------------------------------------------------------------------"
echo ""
read -p "Perform unit tests (phpUnit 3.7 must be installed)? (y/n): " UNIT_TESTS

if [ "$UNIT_TESTS" == "y" ]; then
    while read LINE ; do
        phpunit --colors --verbose "$LINE"
    done < "Test/UnitTests/runconfig.txt"
fi
echo ""


echo "2. INTEGRATIONTESTS"
echo "------------------------------------------------------------------"
echo "Please type in the path to your PHP installation. If you leave the"
echo "field blank, the environment path is used."
echo ""
read -p "Path (e.g. '/usr/local/bin/php'): " PHP_PATH

if [ -z "$PHP_PATH" ]; then
    echo "Using environment path."
    PHP_PATH="php"
fi
echo ""

echo "Integrationtests are being performed..."
echo ""
echo "================================================================="
echo ""
# iterate over the cases
for f in $TEST_CASES
do
    # Check if this is a directory and not a .DS_STORE or thumbs.db file
    if [ -d "$f" ]; then
        # Jump to the case folder
        cd $f

        let DONE=DONE+1 

        # Output the name of the test
        read HEADLINE < description.txt 

        printf "%-4s: %-50s" $DONE "$HEADLINE"

        # Execute the test
        RESULT=$("$PHP_PATH" -f index.php)

        if [ "$RESULT" != "true" ]; then
            echo "failed"
            let FAILED=FAILED+1 
        else
            echo "completed"
        fi

        # Jump back
        cd ../../../
    fi
done

echo ""
echo "================================================================="
echo ""
echo "Tests done: $DONE"
echo "Tests failed: $FAILED"

